Learn R Programming

dsmSearch (version 1.2.2)

lidar_search: lidar_search

Description

The lidar_search function is designed to facilitate the retrieval and exploration of LiDAR (Light Detection and Ranging) data within a specified bounding box (bbox). This function enables users to search for LiDAR data, preview available graphics, and optionally download LiDAR data files for further analysis.

Usage

lidar_search(bbox, max_return = 500, preview = FALSE, folder = "")

Value

dataframe

Arguments

bbox

vector, a bounding box defining the geographical area for the LiDAR data search.

max_return

numeric, indicating the maximum of returns.

preview

logical. If TRUE (default is FALSE), enable or disable previewing LiDAR graphics.

folder

string (optional), indicating an optional folder path where downloaded LiDAR data files will be saved.

Examples

Run this code
# \donttest{
bbox <- c(-83.742282,42.273389,-83.733442,42.278724)
search_result <- dsmSearch::lidar_search(bbox = bbox,
                                         max_return = 25,
                                         preview = FALSE)
# }

Run the code above in your browser using DataLab